FunStateRefresherObx<T> class

支持下拉刷新和上拉加载更多

Inheritance
Available extensions

Constructors

FunStateRefresherObx({Key? key, required FunStateListRefresherController<T> controller, required FunStateBuilder builder, Widget? onLoading, Widget? onEmpty, FunStateErrorBuilder? onError, bool enablePullUp = false, Widget? header, Widget? footer})
const

Properties

builder → FunStateBuilder
StateWidget
final
controller → FunStateListRefresherController<T>
final
enablePullUp → bool
copy from SmartRefresher
final
fill → Widget

Available on Widget, provided by the WidgetExtension extension

撑满父组件
no setter
flex1 → Widget

Available on Widget, provided by the WidgetExtension extension

no setter
flex2 → Widget

Available on Widget, provided by the WidgetExtension extension

no setter
final
hashCode → int
The hash code for this object.
no setterinherited
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEmpty → Widget?
final
onError → FunStateErrorBuilder?
final
onLoading → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expandToScroll({double? minHeight}) → Widget

Available on Widget, provided by the WidgetExtension extension

用于键盘弹出后,底部按钮被遮盖问题 场景:如登录页表单弹出
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited