FunStateBehavior class

FunState全局配置

Constructors

FunStateBehavior({required FunStatePaging paging})

Properties

hashCode → int
The hash code for this object.
no setterinherited
paging → FunStatePaging
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldNotify(covariant FunStateBehavior oldDelegate) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited